@@ -1,16 +1,12 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Visitor-Encode/trunk/lib/Data/Visitor/Encode.pm 100930 2009-02-20T00:59:21.510113Z daisuke  $
-#
-# Copyright (c) 2006 Daisuke Maki <daisuke@endeworks.jp>
-# All rights reserved.
 
 package Data::Visitor::Encode;
-use Any::Moose;
+use Moose;
 use Encode();
 use Scalar::Util ();
 
 extends 'Data::Visitor';
 
-our $VERSION = '0.10004';
+our $VERSION = '0.10005';
 
 has 'visit_method' => (
     is => 'rw',
@@ -23,7 +19,7 @@ has 'extra_args' => (
 
 __PACKAGE__->meta->make_immutable;
 
-no Any::Moose;
+no Moose;
 
 sub _object { ref $_[0] ? $_[0] : $_[0]->new }
 
